@@ -4,7 +4,7 @@ from mprop import mproperty
 from subprocess import Popen, PIPE
 import sys
 
-__version__ = "0.105.1"
+__version__ = "0.106.5"
 
 __github_repo = "jupyter-naas/drivers"
 
@@ -427,3 +427,10 @@ def snowflake():
     from naas_drivers.tools.snowflake import Snowflake
 
     return Snowflake()
+
+
+@load_driver(extra_requires="google-cloud-bigquery,pandas-gbq")
+def bigquery():
+    from naas_drivers.tools.bigquery import BigQuery
+
+    return BigQuery()
